from src import *
clipboard = get_clipboard()
#monitors = get_monitors()
#for monitor_index,monitor in  enumerate(monitors):

AUTO_DICTS = {
    "prompt":{"text":
              ['ask',' ','anything'],
              "image":[],
              "functions":
              [get_paste_in_prompt]
              },
    "enter":{"text":
             [],
             "image":
             ["/home/computron/Pictures/Screenshots/Screenshot from 2025-06-09 06-37-25.png"],
             "functions":
             [get_html_inspect]
             },
    "inspect":{"text":
               ['ask',' ','anything'],"image":[],
               "functions":
               [get_html_inspect]
               }
    }


def get_browser_tab_and_index(url,title):
    get_open_browser_tab(url=url, title=title)
    wid,monitor_index = get_switch_window(window_title=title)
    return wid,monitor_index
def get_gpt_browser():
    wid,monitor_index = get_browser_tab_and_index(url='https://chatgpt.com',
                          title="chatgpt")
    return wid,monitor_index
def get_all_pointer_functions():
    for key,auto_dict in auto_dicts.items():
def get_pointer_function(key=None,
                         text=None,
                         image=None,
                         functions=None,
                         index=None,
                         output_file=None):
    if key:
        audo_dict = AUTO_DICTS.get(key)
    if audo_dict:
        text = auto_dict.get('text',[])
        target_image = auto_dict.get('image',[])
        functions = auto_dict.get('functions',[])
    target_text = text or []
    target_image = target_image or []
    functions = functions or []
    monitor_index = index or 1
    output_file = output_file or 'snapshot.png'
    scnShtMgr = screenshotManager(output_file=output_file,
                                  monitor_index=monitor_index,
                                  functions=functions,
                                  target_image=target_image,
                                  target_text=target_text)

    

    




from abstract_flask import *
from ...imports import *
response_bp,logger = get_bp('response_bp',__name__,
                            url_prefix=URL_PREFIX,
                            static_folder=RESPONSE_DIR)
@response_bp.route('/response',methods=["POST","GET"])
def ReSpOnSe():
    data = parse_and_spec_vars(flask_request,['response'])
    response = data.get('response')
    safe_dump_to_file(data=response,file_path=RESPONSE_FILE_PATH)



import threading
from ...imports import *
watcher_bp,logger = get_bp('watcher_bp',__name__,
                         url_prefix=URL_PREFIX,
                         static_folder=STATIC_FOLDER)


@watcher_bp.route('/start', methods=['GET'])
def start():
    start_watchers()
    return "File watchers started"

@watcher_bp.route('/')
def index():
    return "File watcher Flask app running"





from abstract_flask import *
from ...imports import *
query_bp,logger = get_bp('query_bp',__name__,
                         url_prefix=URL_PREFIX,
                         static_folder=QUERY_DIR)
@query_bp.route('/query',methods=["POST","GET"])
def QuErY():
    data = parse_and_spec_vars(flask_request,['query'])
    query = data.get('query')
    safe_dump_to_file(data=query,file_path=QUERY_FILE_PATH)



from .shadow_main import *

def monitor_clipboard(interval=0.5):
    return clipboard.monitor_clipboard(interval=interval)

def start_monitoring():
    return clipboard.start_monitoring()

def stop_monitoring():
    return clipboard.stop_monitoring()



import os
import sys

# ——— Privilege dropping ———
if "SUDO_UID" in os.environ and "SUDO_GID" in os.environ:
    os.setgid(int(os.environ["SUDO_GID"]))
    os.setuid(int(os.environ["SUDO_UID"]))

from PyQt5.QtWidgets import (
    QApplication, QDialog, QVBoxLayout, QLabel,
    QLineEdit, QDialogButtonBox, QPushButton
)
from PyQt5.QtCore import Qt

class InputDialog(QDialog):
    def __init__(self):
        super().__init__(flags=Qt.Window)
        self.setWindowTitle(title)
        self.exit_requested = False

        layout = QVBoxLayout(self)
        layout.addWidget(QLabel(prompt))

        self.line_edit = QLineEdit(self)
        layout.addWidget(self.line_edit)

        buttons = QDialogButtonBox(
            QDialogButtonBox.Ok | QDialogButtonBox.Cancel,
            parent=self
        )
        buttons.accepted.connect(self.accept)
        buttons.rejected.connect(self.reject)
        layout.addWidget(buttons)

        exit_btn = QPushButton("Exit", self)
        exit_btn.clicked.connect(self._on_exit)
        layout.addWidget(exit_btn, alignment=Qt.AlignRight)

    def _on_exit(self):
        self.exit_requested = True
        self.reject()
InputDialog()



import webbrowser
from PIL import Image
import pytesseract
import mss
import pyperclip
import time
import threading
import platform
import os
import subprocess
import time
import json
import math
import sys

from typing import (Any,
                    Dict,
                    List,
                    Optional,
                    Tuple
                    )
from abstract_utilities import (SingletonMeta,
                                safe_dump_to_file,
                                safe_load_from_file
                                )
from abstract_utilities.class_utils import get_class_inputs as get_inputs
from abstract_utilities.compare_utils import get_closest_match_from_list
from pynput import mouse, keyboard
from random import uniform
import base64
import uuid
import pytesseract
pytesseract.pytesseract.tesseract_cmd = '/home/computron/miniconda/bin/tesseract'

# get a UUID - URL safe, Base64
import uuid

def get_uuid_id():
    return str(uuid.uuid4())
# ——— Globals ———
def get_abs_file():
    return os.path.abspath(__file__)
def get_abs_dir():
    abs_file = get_abs_file()
    return os.path.dirname(abs_file)
def get_abs_path(path):
    abs_dir = get_abs_dir()
    return os.path.join(abs_dir,path)
def get_abs_parent_path(path):
    abs_dir = get_abs_dir()
    dirname = os.path.dirname(abs_dir)
    return os.path.join(dirname,path)
def get_rel_dir():
    rel_dir = os.getcwd()
    return rel_dir
def get_rel_path(path):
    rel_dir = get_abs_dir()
    return os.path.join(rel_dir,path)
def get_datas_dir():
    datas_folder  = get_abs_parent_path('datas')
    os.makedirs(datas_folder,exist_ok=True)
    return datas_folder
def get_sessions_dir():
    datas_dir = get_datas_dir()
    sessions_folder  = os.path.join(datas_dir,'sessions')
    os.makedirs(sessions_folder,exist_ok=True)
    return sessions_folder

def get_chat_dirs():
    datas_dir = get_datas_dir()
    chat_dirs  = os.path.join(datas_dir,'chatDirs')
    os.makedirs(chat_dirs,exist_ok=True)
    return chat_dirs

def get_queries_dir():
    chat_dirs = get_chat_dirs()
    queries_dir  = os.path.join(chat_dirs,'queries')
    os.makedirs(queries_dir,exist_ok=True)
    return queries_dir

def get_prompts_dir():
    chat_dirs = get_chat_dirs()
    prompts_dir = os.path.join(chat_dirs,'prompts')
    os.makedirs(prompts_dir,exist_ok=True)
    return prompts_dir

def get_responses_dir():
    chat_dirs = get_chat_dirs()
    responses_dir = os.path.join(chat_dirs,'responses')
    os.makedirs(responses_dir,exist_ok=True)
    return responses_dir

def get_queried_dir():
    chat_dirs = get_chat_dirs()
    queried_dir = os.path.join(chat_dirs,'queried')
    os.makedirs(queried_dir,exist_ok=True)
    return queried_dir

def get_response_path(path=None):
    path = path or 'new_response.txt'
    responses_dir = get_responses_dir()
    response_file_path = os.path.join(responses_dir,path)
    return response_file_path

def get_query_path(path=None):
    path = path or 'new_query.txt'
    queries_dir = get_queries_dir()
    query_file_path = os.path.join(queries_dir,path)
    return query_file_path

def get_prompt_path(path=None):
    path = path or 'new_prompt.txt'
    prompts_dir = get_prompts_dir()
    prompt_file_path = os.path.join(prompts_dir,path)
    return prompt_file_path

def get_events_path(path,default=None):
    path = path or default or "session.json"
    if os.path.exists(path):
        return path
    dirname = os.path.dirname(path)
    if dirname and os.path.isdir(dirname):
        return path
    return get_rel_path(path)

def get_time():
    return time.time()

def get_time_span(start_time):
    time_span = get_time() - start_time
    return time_span

def resolve_events_path(path, default=None):
    path = path or default or get_rel_path("session.json")
    dirname = os.path.dirname(path)
    if os.path.exists(path):
        return path
    dirname = os.path.dirname(path)
    if dirname and os.path.isdir(dirname):
        return path
    return get_rel_path(path)


def get_default_session_path():
    sessions_dir = get_sessions_dir()
    uuid = get_uuid_id()
    default_session_path = os.path.join(sessions_dir,f'{uuid}_default.json')
    return default_session_path
# Time utilities
def now() -> float:
    return time.time()

def elapsed(start: float) -> float:
    return now() - start
